%Zeitbereichsanalyse mit Auslesen der Messwerte
%
%   28.08.2019          T. Weber    
%   12.12.2020          Auslesen der Messwerte hinzugefgt

close all;
clear;

vna = 'none'; % SELECT YOUR VECTOR NETWORK ANALYZER HERE

whandle = @hann; % zu verwendende Fensterfunktion
over = 16; % berabtastungsfaktor

% Messung
obj = vna_connect(vna); % Verbindung zum VNA aufbauen
[s,frequency] = vna_capture(obj,'dut_port1.dat'); % Messwerte vom VNA auslesen
vna_disconnect(obj); % Verbindung zum VNA schlieen

% komplexwertige Impulsantwort im quivalenten Tiefpassbereich berechnen
[h_bandpass,t_bandpass] = tda_bandpass(frequency,s,whandle,over);
data = [t_bandpass(:),real(h_bandpass(:)),imag(h_bandpass(:))];
save('tda_bandpass.txt','data','-ascii');

% Impulsantwort zeichnen
figure;
plot(t_bandpass,abs(h_bandpass),'r-');
hold on;
plot(t_bandpass,real(h_bandpass),'g-');
plot(t_bandpass,imag(h_bandpass),'b-');
hold off;

% formatieren
axis([t_bandpass(1) t_bandpass(end) -1.5 1.5]);
yticks(-1.5:0.5:1.5);
grid on;
grid minor;
xlabel('t/s');
legend('|h(t)|','Re(h(t))','Im(h(t))');
title('Bandpassmodus');

% reellwertige Impulsantwort im Bandpassbereich berechnen
[h_tiefpass,t_tiefpass] = tda_tiefpass(frequency,s,whandle,over);
data = [t_tiefpass(:),h_tiefpass(:)];
save('tda_tiefpass.txt','data','-ascii');

% Impulsantwort zeichnen
figure;
plot(t_tiefpass,h_tiefpass,'r-');

% formatieren
axis([t_tiefpass(1) t_tiefpass(end) -1.5 1.5]);
yticks(-1.5:0.5:1.5);
grid on;
grid minor;
xlabel('t/s');
legend('h(t)');
title('Tiefpassmodus');
